@@ -30,6 +30,7 @@
 
 // KDE
 #include <KConfigGroup>
+#include <KMimeTypeTrader>
 #include <KService>
 #include <KDesktopFile>
 #include <KLocalizedString>
@@ -109,7 +110,21 @@ public:
     static QList<QString> defaultFavorites()
     {
         QList<QString> applications;
-        applications << "konqbrowser" << "KMail2" << "systemsettings" << "dolphin" << "org.kde.konsole" << "org.kde.kwrite";
+
+        KConfigGroup config(KSharedConfig::openConfig(), "General");
+        QString browser = config.readPathEntry("BrowserApplication", QString());
+
+        if (browser.isEmpty()) {
+            const KService::Ptr htmlApp = KMimeTypeTrader::self()->preferredService(QLatin1String("text/html"));
+
+            if (htmlApp) {
+                browser = htmlApp->storageId().replace(QLatin1String(".desktop"), QString());
+            }
+        } else if (browser.startsWith('!')) {
+            browser = browser.mid(1);
+        }
+
+        applications << browser << "kontact" << "systemsettings" << "dolphin" << "ktp-contactlist" << "kate";
 
         QList<QString> desktopFiles;
 
