@@ -26,6 +26,7 @@
 #include <tasksmodel.h>
 
 class QQuickItem;
+class QQuickWindow;
 
 class Backend : public QObject
 {
@@ -34,6 +35,7 @@ class Backend : public QObject
     Q_PROPERTY(QObject* groupManager READ groupManager CONSTANT)
     Q_PROPERTY(QObject* tasksModel READ tasksModel CONSTANT)
     Q_PROPERTY(QQuickItem* taskManagerItem READ taskManagerItem WRITE setTaskManagerItem NOTIFY taskManagerItemChanged)
+    Q_PROPERTY(QQuickItem* toolTipItem READ toolTipItem WRITE setToolTipItem NOTIFY toolTipItemChanged)
     Q_PROPERTY(bool anyTaskNeedsAttention READ anyTaskNeedsAttention)
     Q_PROPERTY(bool highlightWindows READ highlightWindows WRITE setHighlightWindows NOTIFY highlightWindowsChanged)
     Q_PROPERTY(int groupingStrategy READ groupingStrategy WRITE setGroupingStrategy)
@@ -50,6 +52,9 @@ class Backend : public QObject
         QQuickItem* taskManagerItem() const;
         void setTaskManagerItem(QQuickItem *item);
 
+        QQuickItem* toolTipItem() const;
+        void setToolTipItem(QQuickItem *item);
+
         bool anyTaskNeedsAttention() const;
 
         bool highlightWindows() const;
@@ -70,6 +75,7 @@ class Backend : public QObject
         void activateItem(int id, bool toggle);
         void activateWindow(int winId);
         void closeWindow(int winId);
+        void launchNewInstance(int id);
         void itemContextMenu(QQuickItem *item, QObject *configAction);
         void itemHovered(int id, bool hovered);
         void windowHovered(int winId, bool hovered);
@@ -79,18 +85,24 @@ class Backend : public QObject
 
     private Q_SLOTS:
         void updateLaunchersCache();
+        void toolTipWindowChanged(QQuickWindow *window);
 
     Q_SIGNALS:
         void taskManagerItemChanged(QQuickItem*);
+        void toolTipItemChanged(QQuickItem*);
         void highlightWindowsChanged(bool);
         void launchersChanged();
 
     private:
+        void updateWindowHighlight();
+
         TaskManager::GroupManager *m_groupManager;
         TaskManager::TasksModel *m_tasksModel;
         QQuickItem* m_taskManagerItem;
-        WId m_lastWindowId;
+        QQuickItem* m_toolTipItem;
+        WId m_panelWinId;
         bool m_highlightWindows;
+        QList<WId> m_windowsToHighlight;
         QString m_launchers;
 };
 
