@@ -41,7 +41,7 @@
 #include <QDebug>
 
 #include "internallibkonq/konq_popupmenu.h"
-#include "internallibkonq/konq_operations.h"
+#include <KIO/DropJob>
 #include <KAuthorized>
 #include <KBookmarkManager>
 #include <KConfigGroup>
@@ -53,16 +53,16 @@
 #include <KIO/FileUndoManager>
 #include <KIO/JobUiDelegate>
 #include <KIO/Paste>
+#include <KIO/PasteJob>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KShell>
-#include <KUrl>
-#include <KUrlMimeData>
 
 #include <KDesktopFile>
 #include <KDirModel>
 #include <KIO/CopyJob>
 #include <KIO/Job>
+#include <KProtocolInfo>
 #include <KRun>
 
 #include <sys/types.h>
@@ -108,6 +108,7 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     dirLister->setDelayedMimeTypes(true);
     dirLister->setAutoErrorHandlingEnabled(false, 0);
     connect(dirLister, SIGNAL(error(QString)), this, SLOT(dirListFailed(QString)));
+    connect(dirLister, SIGNAL(itemsDeleted(KFileItemList)), this, SLOT(evictFromIsDirCache(KFileItemList)));
 
     m_dirModel = new KDirModel(this);
     m_dirModel->setDirLister(dirLister);
@@ -148,6 +149,7 @@ QHash< int, QByteArray > FolderModel::staticRoleNames()
     roleNames[SelectedRole] = "selected";
     roleNames[IsDirRole] = "isDir";
     roleNames[UrlRole] = "url";
+    roleNames[LinkDestinationUrl] = "linkDestinationUrl";
     roleNames[SizeRole] = "size";
     roleNames[TypeRole] = "type";
 
@@ -177,6 +179,7 @@ void FolderModel::setUrl(const QString& url)
 
     beginResetModel();
     m_url = url;
+    m_isDirCache.clear();
     m_dirModel->dirLister()->openUrl(resolvedUrl);
     clearDragImages();
     endResetModel();
@@ -739,7 +742,8 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
     QDropEvent ev(pos, possibleActions, mimeData, buttons, modifiers);
     ev.setDropAction(proposedAction);
 
-    KonqOperations::doDrop(item, m_dirModel->dirLister()->url(), &ev, 0, QList<QAction *>());
+    KIO::DropJob *dropJob = KIO::drop(&ev, m_dirModel->dirLister()->url());
+    dropJob->ui()->setAutoErrorHandlingEnabled(true);
 }
 
 void FolderModel::selectionChanged(QItemSelection selected, QItemSelection deselected)
@@ -787,9 +791,27 @@ QVariant FolderModel::data(const QModelIndex& index, int role) const
     } else if (role == SelectedRole) {
         return m_selectionModel->isSelected(index);
     } else if (role == IsDirRole) {
-        return isDir(mapToSource(index), m_dirModel);
+        const QUrl &url = data(index, UrlRole).value<QUrl>();
+
+        if (m_isDirCache.contains(url)) {
+            return m_isDirCache[url];
+        } else {
+            return isDir(mapToSource(index), m_dirModel);
+        }
     } else if (role == UrlRole) {
         return itemForIndex(index).url();
+    } else if (role == LinkDestinationUrl) {
+        const KFileItem item = itemForIndex(index);
+
+        if (m_parseDesktopFiles && item.isDesktopFile()) {
+            const KDesktopFile file(item.targetUrl().path());
+
+            if (file.readType() == "Link") {
+                return file.readUrl();
+            }
+        }
+
+        return item.url();
     } else if (role == SizeRole) {
         return m_dirModel->data(mapToSource(QSortFilterProxyModel::index(index.row(), 1)), Qt::DisplayRole);
     } else if (role == TypeRole) {
@@ -821,14 +843,22 @@ bool FolderModel::isDir(const QModelIndex &index, const KDirModel *dirModel) con
     if (m_parseDesktopFiles && item.isDesktopFile()) {
         // Check if the desktop file is a link to a directory
         KDesktopFile file(item.targetUrl().path());
+
         if (file.readType() == "Link") {
             const QUrl url(file.readUrl());
+
             if (url.isLocalFile()) {
                 QT_STATBUF buf;
                 const QString path = url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
                 if (QT_STAT(QFile::encodeName(path).constData(), &buf) == 0) {
                     return S_ISDIR(buf.st_mode);
                 }
+            } else if (!m_isDirCache.contains(item.url()) && KProtocolInfo::protocolClass(url.scheme()) == QString(":local")) {
+                KIO::StatJob *job = KIO::stat(url, KIO::HideProgressInfo);
+                job->setProperty("org.kde.plasma.folder_url", item.url());
+                job->setSide(KIO::StatJob::SourceSide);
+                job->setDetails(0);
+                connect(job, SIGNAL(result(KJob*)), this, SLOT(statResult(KJob*)));
             }
         }
     }
@@ -836,6 +866,27 @@ bool FolderModel::isDir(const QModelIndex &index, const KDirModel *dirModel) con
     return false;
 }
 
+void FolderModel::statResult(KJob *job)
+{
+    KIO::StatJob *statJob = static_cast<KIO::StatJob*>(job);
+
+    const QUrl &url = statJob->property("org.kde.plasma.folder_url").value<QUrl>();
+    const QModelIndex &idx = index(indexForUrl(url), 0);
+
+    if (idx.isValid()) {
+        m_isDirCache[url] = statJob->statResult().isDir();
+
+        emit dataChanged(idx, idx, QVector<int>() << IsDirRole);
+    }
+}
+
+void FolderModel::evictFromIsDirCache(const KFileItemList& items)
+{
+    foreach (const KFileItem &item, items) {
+        m_isDirCache.remove(item.url());
+    }
+}
+
 bool FolderModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
     const KDirModel *dirModel = static_cast<KDirModel*>(sourceModel());
@@ -1039,14 +1090,17 @@ void FolderModel::updateActions()
     QAction *paste = m_actionCollection.action("paste");
 
     if (paste) {
-        const QString pasteText = KIO::pasteActionText();
+        bool enable = false;
 
-        if (pasteText.isEmpty()) {
-            paste->setText(i18n("&Paste"));
-            paste->setEnabled(false);
-        } else {
+        const QString pasteText = KIO::pasteActionText(QApplication::clipboard()->mimeData(),
+            &enable, m_dirModel->dirLister()->rootItem());
+
+        if (enable) {
             paste->setText(pasteText);
             paste->setEnabled(true);
+        } else {
+            paste->setText(i18n("&Paste"));
+            paste->setEnabled(false);
         }
 
         QAction* pasteTo = m_actionCollection.action("pasteto");
@@ -1188,14 +1242,14 @@ void FolderModel::cut()
 
 void FolderModel::paste()
 {
-    KonqOperations::doPaste(QApplication::desktop(), m_dirModel->dirLister()->url());
+    KIO::paste(QApplication::clipboard()->mimeData(), m_dirModel->dirLister()->url());
 }
 
 void FolderModel::pasteTo()
 {
     const QList<QUrl> urls = selectedUrls(false);
     Q_ASSERT(urls.count() == 1);
-    KonqOperations::doPaste(QApplication::desktop(), urls.first());
+    KIO::paste(QApplication::clipboard()->mimeData(), urls.first());
 }
 
 void FolderModel::refresh()
