@@ -21,17 +21,20 @@
 #include "foldermodel.h"
 
 #include <QDebug>
+#include <QTimer>
 
 Positioner::Positioner(QObject *parent): QAbstractItemModel(parent)
 , m_enabled(false)
 , m_folderModel(0)
 , m_perStripe(0)
-, m_pendingPositionsUpdate(false)
-, m_applyPositions(false)
-, m_resetting(false)
-, m_lastIndex(-1)
+, m_lastRow(-1)
 , m_ignoreNextTransaction(false)
+, m_pendingPositions(false)
+, m_updatePositionsTimer(new QTimer(this))
 {
+    m_updatePositionsTimer->setSingleShot(true);
+    m_updatePositionsTimer->setInterval(0);
+    connect(m_updatePositionsTimer, SIGNAL(timeout()), this, SLOT(updatePositions()));
 }
 
 Positioner::~Positioner()
@@ -46,11 +49,11 @@ bool Positioner::enabled() const
 void Positioner::setEnabled(bool enabled)
 {
     if (m_enabled != enabled) {
-        beginResetModel();
-
         m_enabled = enabled;
 
-        if (enabled) {
+        beginResetModel();
+
+        if (enabled && m_folderModel) {
             initMaps();
         }
 
@@ -58,9 +61,8 @@ void Positioner::setEnabled(bool enabled)
 
         emit enabledChanged();
 
-        if (!m_pendingPositionsUpdate && m_folderModel->rowCount()) {
-            m_pendingPositionsUpdate = true;
-            QMetaObject::invokeMethod(this, "updatePositions", Qt::QueuedConnection);
+        if (!enabled) {
+            m_updatePositionsTimer->start();
         }
     }
 }
@@ -84,6 +86,10 @@ void Positioner::setFolderModel(QObject *folderModel)
 
         if (m_folderModel) {
             connectSignals(m_folderModel);
+
+            if (m_enabled) {
+                initMaps();
+            }
         }
 
         endResetModel();
@@ -102,15 +108,8 @@ void Positioner::setPerStripe(int perStripe)
     if (m_perStripe != perStripe) {
         m_perStripe = perStripe;
 
-        emit perStripeChanged();
-
-        if (m_enabled && m_perStripe > 0) {
+        if (m_enabled && perStripe > 0 && !m_proxyToSource.isEmpty()) {
             applyPositions();
-
-            if (!m_pendingPositionsUpdate) {
-                m_pendingPositionsUpdate = true;
-                QMetaObject::invokeMethod(this, "updatePositions", Qt::QueuedConnection);
-            }
         }
     }
 }
@@ -126,12 +125,18 @@ void Positioner::setPositions(QStringList positions)
         m_positions = positions;
 
         emit positionsChanged();
+
+        if (!m_proxyToSource.isEmpty()) {
+            applyPositions();
+        } else if (m_positions.size() >= 5) {
+            m_pendingPositions = true;
+        }
     }
 }
 
 int Positioner::map(int row) const
 {
-    if (m_enabled) {
+    if (m_enabled && m_folderModel) {
         if (m_proxyToSource.contains(row)) {
             return m_proxyToSource.value(row);
         } else {
@@ -142,6 +147,77 @@ int Positioner::map(int row) const
     return row;
 }
 
+int Positioner::nearestItem(int currentIndex, Qt::ArrowType direction)
+{
+    if (!m_enabled || currentIndex >= rowCount()) {
+        return -1;
+    }
+
+    if (currentIndex < 0) {
+        return firstRow();
+    }
+
+    int hDirection = 0;
+    int vDirection = 0;
+
+    switch (direction) {
+        case Qt::LeftArrow:
+            hDirection = -1;
+            break;
+        case Qt::RightArrow:
+            hDirection = 1;
+            break;
+        case Qt::UpArrow:
+            vDirection = -1;
+            break;
+        case Qt::DownArrow:
+            vDirection = 1;
+            break;
+        default:
+            return -1;
+    }
+
+    QList<int> rows(m_proxyToSource.keys());
+    qSort(rows);
+
+    int nearestItem = -1;
+    const QPoint currentPos(currentIndex % m_perStripe, currentIndex / m_perStripe);
+    int lastDistance = -1;
+    int distance = 0;
+
+    foreach (int row, rows) {
+        const QPoint pos(row % m_perStripe, row / m_perStripe);
+
+        if (row == currentIndex) {
+            continue;
+        }
+
+        if (hDirection == 0) {
+            if (vDirection * pos.y() > vDirection * currentPos.y()) {
+                distance = (pos - currentPos).manhattanLength();
+
+                if (nearestItem == -1 || distance < lastDistance
+                    || (distance == lastDistance && pos.x() == currentPos.x())) {
+                    nearestItem = row;
+                    lastDistance = distance;
+                }
+            }
+        } else if (vDirection == 0) {
+            if (hDirection * pos.x() > hDirection * currentPos.x()) {
+                distance = (pos - currentPos).manhattanLength();
+
+                if (nearestItem == -1 || distance < lastDistance
+                    || (distance == lastDistance && pos.y() == currentPos.y())) {
+                    nearestItem = row;
+                    lastDistance = distance;
+                }
+            }
+        }
+    }
+
+    return nearestItem;
+}
+
 bool Positioner::isBlank(int row) const
 {
     if (!m_enabled && m_folderModel) {
@@ -181,13 +257,32 @@ int Positioner::indexForUrl(const QUrl &url) const
     return -1;
 }
 
-QHash< int, QByteArray > Positioner::roleNames() const
+void Positioner::setRangeSelected(int anchor, int to)
 {
-    if (m_folderModel) {
-        return m_folderModel->roleNames();
+    if (!m_folderModel) {
+        return;
     }
 
-    return QAbstractItemModel::roleNames();
+    if (m_enabled) {
+        QVariantList indices;
+
+        for (int i = qMin(anchor, to); i <= qMax(anchor, to); ++i) {
+            if (m_proxyToSource.contains(i)) {
+                indices.append(m_proxyToSource.value(i));
+            }
+        }
+
+        if (indices.count()) {
+            m_folderModel->updateSelection(indices, false);
+        }
+    } else {
+        m_folderModel->setRangeSelected(anchor, to);
+    }
+}
+
+QHash< int, QByteArray > Positioner::roleNames() const
+{
+    return FolderModel::staticRoleNames();
 }
 
 QModelIndex Positioner::index(int row, int column, const QModelIndex &parent) const
@@ -233,7 +328,7 @@ int Positioner::rowCount(const QModelIndex& parent) const
 {
     if (m_folderModel) {
         if (m_enabled) {
-            return lastIndex() + 1;
+            return lastRow() + 1;
         } else {
             return m_folderModel->rowCount(parent);
         }
@@ -255,78 +350,97 @@ int Positioner::columnCount(const QModelIndex& parent) const
 
 void Positioner::reset()
 {
-    m_resetting = true;
-
     beginResetModel();
 
     initMaps();
 
+    endResetModel();
+
     m_positions = QStringList();
     emit positionsChanged();
-
-    endResetModel();
 }
 
-void Positioner::move(int from, int to) {
-    if (!m_proxyToSource.contains(from) || from == to) {
-        return;
+void Positioner::move(const QVariantList &moves) {
+    QVector<int> fromIndices;
+    QVector<int> toIndices;
+    QVector<int> sourceRows;
+
+    for (int i = 0; i < moves.count(); ++i) {
+        const int isFrom = (i % 2 == 0);
+        const int v = moves[i].toInt();
+
+        if (isFrom) {
+            if (m_proxyToSource.contains(v)) {
+                sourceRows.append(m_proxyToSource.value(v));
+            } else {
+                sourceRows.append(-1);
+            }
+        }
+
+        (isFrom ? fromIndices : toIndices).append(v);
     }
 
-    if (to == -1) {
-        to = firstFreeRow();
+    const int oldCount = rowCount();
+
+    for (int i = 0; i < fromIndices.count(); ++i)
+    {
+        const int from = fromIndices[i];
+        int to = toIndices[i];
+        const int sourceRow = sourceRows[i];
+
+        if (!sourceRow == -1 || from == to) {
+            continue;
+        }
 
         if (to == -1) {
-            to = lastIndex() + 1;
+            to = firstFreeRow();
+
+            if (to == -1) {
+                to = lastRow() + 1;
+            }
+        }
+
+        if (!fromIndices.contains(to) && !isBlank(to)) {
+            continue;
+        }
+
+        toIndices[i] = to;
+
+        if (!toIndices.contains(from)) {
+            m_proxyToSource.remove(from);
+        }
+
+        updateMaps(to, sourceRow);
+
+        const QModelIndex &fromIdx = index(from, 0);
+        emit dataChanged(fromIdx, fromIdx);
+
+        if (to < oldCount) {
+            const QModelIndex &toIdx = index(to, 0);
+            emit dataChanged(toIdx, toIdx);
         }
     }
 
-    if (!isBlank(to)) {
-        return;
-    }
+    const int newCount = rowCount();
 
-    int oldCount = rowCount();
-
-    int sourceRow = m_proxyToSource.value(from);
-    m_proxyToSource.remove(from);
-    m_proxyToSource.insert(to, sourceRow);
-    m_lastIndex = -1;
-    m_sourceToProxy.insert(sourceRow, to);
-
-    const QModelIndex &fromIdx = index(from, 0);
-    emit dataChanged(fromIdx, fromIdx);
-
-    if (to < oldCount) {
-        const QModelIndex &toIdx = index(to, 0);
-        emit dataChanged(toIdx, toIdx);
-    } else {
-        beginInsertRows(QModelIndex(), oldCount, to);
+    if (newCount > oldCount) {
+        beginInsertRows(QModelIndex(), oldCount, newCount - 1);
         endInsertRows();
     }
 
-    int newCount = rowCount();
-
     if (newCount < oldCount) {
         beginRemoveRows(QModelIndex(), newCount, oldCount - 1);
         endRemoveRows();
     }
 
-    if (!m_pendingPositionsUpdate) {
-        m_pendingPositionsUpdate = true;
-        QMetaObject::invokeMethod(this, "updatePositions", Qt::QueuedConnection);
-    }
+    m_updatePositionsTimer->start();
 }
 
 void Positioner::updatePositions()
 {
-    if (m_perStripe < 1) {
-        m_pendingPositionsUpdate = false;
-
-        return;
-    }
-
     QStringList positions;
 
-    if (m_enabled && !m_proxyToSource.isEmpty()) {
+    if (m_enabled && !m_proxyToSource.isEmpty() && m_perStripe > 0) {
         positions.append(QString::number((1 + ((rowCount() - 1) / m_perStripe))));
         positions.append(QString::number(m_perStripe));
 
@@ -339,7 +453,7 @@ void Positioner::updatePositions()
                 FolderModel::UrlRole).toString();
 
             if (name.isEmpty()) {
-                qDebug() << it.value() << "Source model doesn't know this index!";
+                qDebug() << this << it.value() << "Source model doesn't know this index!";
 
                 return;
             }
@@ -350,9 +464,11 @@ void Positioner::updatePositions()
         }
     }
 
-    setPositions(positions);
+    if (positions != m_positions) {
+        m_positions = positions;
 
-    m_pendingPositionsUpdate = false;
+        emit positionsChanged();
+    }
 }
 
 void Positioner::sourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
@@ -381,19 +497,21 @@ void Positioner::sourceModelAboutToBeReset()
 
 void Positioner::sourceModelReset()
 {
+    if (m_enabled) {
+        initMaps();
+    }
+
     emit endResetModel();
 }
 
 void Positioner::sourceRowsAboutToBeInserted(const QModelIndex &parent, int start, int end)
 {
     if (m_enabled) {
-        if (m_sourceToProxy.isEmpty()) {
-            if (m_positions.isEmpty()) {
+        if (m_proxyToSource.isEmpty()) {
+            if (!m_pendingPositions) {
                 emit beginInsertRows(parent, start, end);
 
-                initMaps(end);
-            } else {
-                m_applyPositions = true;
+                initMaps(end + 1);
             }
 
             return;
@@ -406,9 +524,7 @@ void Positioner::sourceRowsAboutToBeInserted(const QModelIndex &parent, int star
             free = firstFreeRow();
 
             if (free != -1) {
-                m_proxyToSource.insert(free, i);
-                m_lastIndex = -1;
-                m_sourceToProxy.insert(i, free);
+                updateMaps(free, i);
                 m_pendingChanges << createIndex(free, 0);
             } else {
                 rest = i;
@@ -417,15 +533,13 @@ void Positioner::sourceRowsAboutToBeInserted(const QModelIndex &parent, int star
         }
 
         if (rest != -1) {
-            int firstNew = lastIndex() + 1;
+            int firstNew = lastRow() + 1;
             int remainder = (end - rest);
 
             beginInsertRows(parent, firstNew, firstNew + remainder);
 
             for (int i = 0; i <= remainder; ++i) {
-                m_proxyToSource.insert(firstNew + i, rest +i);
-                m_lastIndex = -1;
-                m_sourceToProxy.insert(rest + i, firstNew + i);
+                updateMaps(firstNew + i, rest + i);
             }
         } else {
             m_ignoreNextTransaction = true;
@@ -438,55 +552,42 @@ void Positioner::sourceRowsAboutToBeInserted(const QModelIndex &parent, int star
 void Positioner::sourceRowsAboutToBeMoved(const QModelIndex &sourceParent, int sourceStart,
     int sourceEnd, const QModelIndex& destinationParent, int destinationRow)
 {
-    qDebug();
-
     emit beginMoveRows(sourceParent, sourceStart, sourceEnd, destinationParent, destinationRow);
 }
 
 void Positioner::sourceRowsAboutToBeRemoved(const QModelIndex &parent, int first, int last)
 {
     if (m_enabled) {
-        int oldLast = lastIndex();
+        int oldLast = lastRow();
 
         for (int i = first; i <= last; ++i) {
             int proxyRow = m_sourceToProxy.take(i);
             m_proxyToSource.remove(proxyRow);
-
-            QHash<int, int> newProxyToSource;
-            QHashIterator<int, int> it(m_proxyToSource);
-
-            while (it.hasNext()) {
-                it.next();
-
-                if (it.value() > i) {
-                    newProxyToSource.insert(it.key(), it.value() - 1);
-                } else {
-                    newProxyToSource.insert(it.key(), it.value());
-                }
-            }
-
-            m_proxyToSource = newProxyToSource;
-            m_lastIndex = -1;
-
-            QHash<int, int> newSourceToProxy;
-            QHashIterator<int, int> it2(m_sourceToProxy);
-
-            while (it2.hasNext()) {
-                it2.next();
-
-                if (it2.key() > i) {
-                    newSourceToProxy.insert(it2.key() - 1, it2.value());
-                } else {
-                    newSourceToProxy.insert(it2.key(), it2.value());
-                }
-            }
-
-            m_sourceToProxy = newSourceToProxy;
-
             m_pendingChanges << createIndex(proxyRow, 0);
         }
 
-        int newLast = lastIndex();
+        QHash<int, int> newProxyToSource;
+        QHash<int, int> newSourceToProxy;
+        QHashIterator<int, int> it(m_sourceToProxy);
+        int delta = std::abs(first - last) + 1;
+
+        while (it.hasNext()) {
+            it.next();
+
+            if (it.key() > last) {
+                newProxyToSource.insert(it.value(), it.key() - delta);
+                newSourceToProxy.insert(it.key() - delta, it.value());
+            } else {
+                newProxyToSource.insert(it.value(), it.key());
+                newSourceToProxy.insert(it.key(), it.value());
+            }
+        }
+
+        m_proxyToSource = newProxyToSource;
+        m_sourceToProxy = newSourceToProxy;
+
+        m_lastRow = -1;
+        int newLast = lastRow();
 
         if (oldLast > newLast) {
             int diff = oldLast - newLast;
@@ -499,6 +600,14 @@ void Positioner::sourceRowsAboutToBeRemoved(const QModelIndex &parent, int first
     }
 }
 
+void Positioner::sourceLayoutAboutToBeChanged(const QList<QPersistentModelIndex> &parents,
+    QAbstractItemModel::LayoutChangeHint hint)
+{
+    Q_UNUSED(parents)
+
+    emit layoutAboutToBeChanged(QList<QPersistentModelIndex>(), hint);
+}
+
 void Positioner::sourceRowsInserted(const QModelIndex &parent, int first, int last)
 {
     Q_UNUSED(parent)
@@ -506,12 +615,10 @@ void Positioner::sourceRowsInserted(const QModelIndex &parent, int first, int la
     Q_UNUSED(last)
 
     if (!m_ignoreNextTransaction) {
-        if (!m_applyPositions) {
+        if (!m_pendingPositions) {
             emit endInsertRows();
         } else {
-            if (m_perStripe > 0) {
-                applyPositions();
-            }
+            applyPositions();
         }
     } else {
         m_ignoreNextTransaction = false;
@@ -519,17 +626,12 @@ void Positioner::sourceRowsInserted(const QModelIndex &parent, int first, int la
 
     flushPendingChanges();
 
-    if (!m_pendingPositionsUpdate && !m_applyPositions) {
-        m_pendingPositionsUpdate = true;
-        QMetaObject::invokeMethod(this, "updatePositions", Qt::QueuedConnection);
-    }
+    m_updatePositionsTimer->start();
 }
 
 void Positioner::sourceRowsMoved(const QModelIndex &sourceParent, int sourceStart,
     int sourceEnd, const QModelIndex &destinationParent, int destinationRow)
 {
-    qDebug();
-
     Q_UNUSED(sourceParent)
     Q_UNUSED(sourceStart)
     Q_UNUSED(sourceEnd)
@@ -553,10 +655,19 @@ void Positioner::sourceRowsRemoved(const QModelIndex &parent, int first, int las
 
     flushPendingChanges();
 
-    if (!m_pendingPositionsUpdate) {
-        m_pendingPositionsUpdate = true;
-        QMetaObject::invokeMethod(this, "updatePositions", Qt::QueuedConnection);
+    m_updatePositionsTimer->start();
+}
+
+void Positioner::sourceLayoutChanged(const QList<QPersistentModelIndex>& parents,
+    QAbstractItemModel::LayoutChangeHint hint)
+{
+    Q_UNUSED(parents)
+
+    if (m_enabled) {
+        initMaps();
     }
+
+    emit layoutChanged(QList<QPersistentModelIndex>(), hint);
 }
 
 void Positioner::initMaps(int size)
@@ -565,28 +676,44 @@ void Positioner::initMaps(int size)
     m_sourceToProxy.clear();
 
     if (size == -1) {
-        size = m_folderModel->rowCount() - 1;
+        size = m_folderModel->rowCount();
     }
 
     if (!size) {
         return;
     }
 
-    for (int i = 0; i <= size; ++i) {
-        m_proxyToSource.insert(i, i);
-        m_sourceToProxy.insert(i, i);
+    for (int i = 0; i < size; ++i) {
+        updateMaps(i, i);
     }
-
-    m_lastIndex = -1;
 }
 
-int Positioner::lastIndex() const
+void Positioner::updateMaps(int proxyIndex, int sourceIndex)
+{
+    m_proxyToSource.insert(proxyIndex, sourceIndex);
+    m_sourceToProxy.insert(sourceIndex, proxyIndex);
+    m_lastRow = -1;
+}
+
+int Positioner::firstRow() const
 {
     if (!m_proxyToSource.isEmpty()) {
-        if (m_lastIndex != -1) {
-            return m_lastIndex;
+        QList<int> keys(m_proxyToSource.keys());
+        qSort(keys);
+
+        return keys.first();
+    }
+
+    return -1;
+}
+
+int Positioner::lastRow() const
+{
+    if (!m_proxyToSource.isEmpty()) {
+        if (m_lastRow != -1) {
+            return m_lastRow;
         } else {
-            QList<int> keys = m_proxyToSource.keys();
+            QList<int> keys(m_proxyToSource.keys());
             qSort(keys);
             return keys.last();
         }
@@ -598,7 +725,7 @@ int Positioner::lastIndex() const
 int Positioner::firstFreeRow() const
 {
     if (!m_proxyToSource.isEmpty()) {
-        int last = lastIndex();
+        int last = lastRow();
 
         for (int i = 0; i <= last; ++i) {
             if (!m_proxyToSource.contains(i)) {
@@ -613,46 +740,19 @@ int Positioner::firstFreeRow() const
 void Positioner::applyPositions()
 {
     if (m_positions.size() < 5) {
-        if (m_folderModel) {
-            if (m_resetting) {
-                m_resetting = false;
-            } else {
-                beginResetModel();
-                m_proxyToSource.clear();
-                m_sourceToProxy.clear();
-                endResetModel();
-
-                initMaps();
-                beginInsertRows(QModelIndex(), 0, lastIndex());
-                endInsertRows();
-            }
-        }
-
         return;
     }
 
     beginResetModel();
+
     m_proxyToSource.clear();
     m_sourceToProxy.clear();
-    endResetModel();
 
-    QStringList positions(m_positions);
+    const QStringList &positions = m_positions.mid(2);
 
-    bool ok = false;
-
-    int stripes = positions.takeFirst().toInt(&ok);
-    if (!ok) { return; }
-    int perStripe = positions.takeFirst().toInt(&ok);
-    if (!ok) { return; }
-
-    Q_UNUSED(stripes)
-    Q_UNUSED(perStripe)
-
-    QString name;
-    int stripe = -1;
-    int pos = -1;
-    int sourceIndex = -1;
-    int index = -1;
+    if (positions.count() % 3 != 0) {
+        return;
+    }
 
     QHash<QString, int> sourceIndices;
 
@@ -661,18 +761,25 @@ void Positioner::applyPositions()
             FolderModel::UrlRole).toString(), i);
     }
 
-    int items = positions.count() / 3;
+    QString name;
+    int stripe = -1;
+    int pos = -1;
+    int sourceIndex = -1;
+    int index = -1;
+    bool ok = false;
+    int offset = 0;
 
-    QStringList leftOvers;
-
-    for (int i = 0; i < items; ++i) {
-        name = positions.takeFirst();
-        stripe = positions.takeFirst().toInt(&ok);
-        if (!ok) { return; }
-        pos = positions.takeFirst().toInt(&ok);
+    // Restore positions for items that still fit.
+    for (int i = 0; i < positions.count() / 3; ++i) {
+        offset = i * 3;
+        pos = positions.at(offset + 2).toInt(&ok);
         if (!ok) { return; }
 
         if (pos <= m_perStripe) {
+            name = positions.at(offset);
+            stripe = positions.at(offset + 1).toInt(&ok);
+            if (!ok) { return; }
+
             if (!sourceIndices.contains(name)) {
                 continue;
             } else {
@@ -685,64 +792,56 @@ void Positioner::applyPositions()
                 continue;
             }
 
-            m_proxyToSource.insert(index, sourceIndex);
-            m_lastIndex = -1;
-            m_sourceToProxy.insert(sourceIndex, index);
-
+            updateMaps(index, sourceIndex);
             sourceIndices.remove(name);
-        } else {
-            leftOvers.append(name);
-            leftOvers.append(QString::number(stripe));
-            leftOvers.append(QString::number(pos));
         }
     }
 
-    items = leftOvers.count() / 3;
-
-    for (int i = 0; i < items; ++i) {
-        name = leftOvers.takeFirst();
-        stripe = leftOvers.takeFirst().toInt(&ok);
-        if (!ok) { return; }
-        pos = leftOvers.takeFirst().toInt(&ok);
+    // Find new positions for items that didn't fit.
+    for (int i = 0; i < positions.count() / 3; ++i) {
+        offset = i * 3;
+        pos = positions.at(offset + 2).toInt(&ok);
         if (!ok) { return; }
 
-        if (!sourceIndices.contains(name)) {
-            continue;
-        } else {
-            sourceIndex = sourceIndices.take(name);
+        if (pos > m_perStripe) {
+            name = positions.at(offset);
+
+            if (!sourceIndices.contains(name)) {
+                continue;
+            } else {
+                sourceIndex = sourceIndices.take(name);
+            }
+
+            index = firstFreeRow();
+
+            if (index == -1) {
+                index = lastRow() + 1;
+            }
+
+            updateMaps(index, sourceIndex);
         }
-
-        index = firstFreeRow();
-
-        if (index == -1) {
-            index = lastIndex() + 1;
-        }
-
-        m_proxyToSource.insert(index, sourceIndex);
-        m_lastIndex = -1;
-        m_sourceToProxy.insert(sourceIndex, index);
     }
 
     QHashIterator<QString, int> it(sourceIndices);
 
+    // Find positions for new source items we don't have records for.
     while (it.hasNext()) {
         it.next();
 
         index = firstFreeRow();
 
         if (index == -1) {
-            index = lastIndex() + 1;
+            index = lastRow() + 1;
         }
 
-        m_proxyToSource.insert(index, it.value());
-        m_lastIndex = -1;
-        m_sourceToProxy.insert(it.value(), index);
+        updateMaps(index, it.value());
     }
 
-    m_applyPositions = false;
+    endResetModel();
 
-    beginInsertRows(QModelIndex(), 0, lastIndex());
-    endInsertRows();
+    m_pendingPositions = false;
+
+    m_updatePositionsTimer->start();
 }
 
 void Positioner::flushPendingChanges()
@@ -751,7 +850,7 @@ void Positioner::flushPendingChanges()
         return;
     }
 
-    int last = lastIndex();
+    int last = lastRow();
 
     foreach (const QModelIndex &idx, m_pendingChanges) {
         if (idx.row() <= last) {
@@ -776,6 +875,9 @@ void Positioner::connectSignals(FolderModel* model)
     connect(model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
             this, SLOT(sourceRowsAboutToBeRemoved(QModelIndex,int,int)),
             Qt::UniqueConnection);
+    connect(model, SIGNAL(layoutAboutToBeChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            this, SLOT(sourceLayoutAboutToBeChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            Qt::UniqueConnection);
     connect(model, SIGNAL(rowsInserted(QModelIndex,int,int)),
             this, SLOT(sourceRowsInserted(QModelIndex,int,int)),
             Qt::UniqueConnection);
@@ -785,6 +887,9 @@ void Positioner::connectSignals(FolderModel* model)
     connect(model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
             this, SLOT(sourceRowsRemoved(QModelIndex,int,int)),
             Qt::UniqueConnection);
+    connect(model, SIGNAL(layoutChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            this, SLOT(sourceLayoutChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            Qt::UniqueConnection);
 }
 
 void Positioner::disconnectSignals(FolderModel* model)
@@ -797,10 +902,14 @@ void Positioner::disconnectSignals(FolderModel* model)
             this, SLOT(sourceRowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)));
     disconnect(model, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
             this, SLOT(sourceRowsAboutToBeRemoved(QModelIndex,int,int)));
+    disconnect(model, SIGNAL(layoutAboutToBeChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            this, SLOT(sourceLayoutAboutToBeChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)));
     disconnect(model, SIGNAL(rowsInserted(QModelIndex,int,int)),
             this, SLOT(sourceRowsInserted(QModelIndex,int,int)));
     disconnect(model, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
             this, SLOT(sourceRowsMoved(QModelIndex,int,int,QModelIndex,int)));
     disconnect(model, SIGNAL(rowsRemoved(QModelIndex,int,int)),
             this, SLOT(sourceRowsRemoved(QModelIndex,int,int)));
+    disconnect(model, SIGNAL(layoutChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)),
+            this, SLOT(sourceLayoutChanged(QList<QPersistentModelIndex>,QAbstractItemModel::LayoutChangeHint)));
 }
