@@ -22,7 +22,6 @@
 #include <QtDBus/QtDBus>
 #include <QProcess>
 
-#include <kdebug.h>
 #include <kpluginfactory.h>
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -41,7 +40,6 @@
 
 
 K_PLUGIN_FACTORY(KeyboardFactory, registerPlugin<KeyboardDaemon>();)
-K_EXPORT_PLUGIN(KeyboardFactory("keyboard", "kxkb"))
 
 KeyboardDaemon::KeyboardDaemon(QObject *parent, const QList<QVariant>&)
 	: KDEDModule(parent),
@@ -63,7 +61,7 @@ KeyboardDaemon::KeyboardDaemon(QObject *parent, const QList<QVariant>&)
 	registerListeners();
 
 	LayoutMemoryPersister layoutMemoryPersister(layoutMemory);
-	if( layoutMemoryPersister.restore("kxkb") ) {
+	if( layoutMemoryPersister.restore() ) {
 		if( layoutMemoryPersister.getGlobalLayout().isValid() ) {
 			X11Helper::setLayout(layoutMemoryPersister.getGlobalLayout());
 		}
@@ -74,7 +72,7 @@ KeyboardDaemon::~KeyboardDaemon()
 {
 	LayoutMemoryPersister layoutMemoryPersister(layoutMemory);
 	layoutMemoryPersister.setGlobalLayout(X11Helper::getCurrentLayout());
-	layoutMemoryPersister.save("kxkb");
+	layoutMemoryPersister.save();
 
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.disconnect(QString(), KEYBOARD_DBUS_OBJECT_PATH, KEYBOARD_DBUS_SERVICE_NAME, KEYBOARD_DBUS_CONFIG_RELOAD_MESSAGE, this, SLOT(configureKeyboard()));
@@ -91,10 +89,13 @@ KeyboardDaemon::~KeyboardDaemon()
 
 void KeyboardDaemon::configureKeyboard()
 {
-	kDebug() << "Configuring keyboard";
+	qCDebug(KCM_KEYBOARD) << "Configuring keyboard";
 	init_keyboard_hardware();
 
 	keyboardConfig.load();
+	if( keyboardConfig.configureLayouts ) {
+        XkbHelper::preInitialize();
+	}
 	XkbHelper::initializeKeyboardLayouts(keyboardConfig);
 	layoutMemory.configChanged();
 
@@ -188,7 +189,7 @@ void KeyboardDaemon::globalSettingsChanged(int category)
 void KeyboardDaemon::layoutChanged()
 {
 	//TODO: pass newLayout into layoutTrayIcon?
-        LayoutUnit newLayout = X11Helper::getCurrentLayout();
+    LayoutUnit newLayout = X11Helper::getCurrentLayout();
 
 	layoutMemory.layoutChanged();
 	if( layoutTrayIcon != NULL ) {
@@ -213,7 +214,7 @@ void KeyboardDaemon::layoutMapChanged()
 
 void KeyboardDaemon::switchToNextLayout()
 {
-	kDebug() << "Toggling layout";
+	qCDebug(KCM_KEYBOARD) << "Toggling layout";
 	X11Helper::switchToNextLayout();
 
         LayoutUnit newLayout = X11Helper::getCurrentLayout();
