@@ -17,30 +17,33 @@
    Boston, MA 02110-1301, USA.
  */
 
-#include <k4aboutdata.h>
-#include <KApplication>
-#include <KCmdLineArgs>
+#include <kaboutdata.h>
+#include <QApplication>
+
 #include <KLocalizedString>
+#include <QCommandLineParser>
 
 #include "knetattach.h"
 
 int main(int argc, char **argv) {
     KLocalizedString::setApplicationDomain("knetattach");
 
-	K4AboutData about("knetattach", 0, ki18n("KDE Network Wizard"), "1.0",
-		ki18n("KDE Network Wizard"),
-		K4AboutData::License_GPL,
-		ki18n("(c) 2004 George Staikos"), KLocalizedString(),
-		"http://www.kde.org/");
+	KAboutData aboutData(QLatin1String("knetattach"), i18n("KDE Network Wizard"), "1.0", i18n("KDE Network Wizard"),KAboutLicense::GPL, i18n("(c) 2004 George Staikos"), QLatin1String("http://www.kde.org/"));
 
-	about.addAuthor(ki18n("George Staikos"), ki18n("Primary author and maintainer"), "staikos@kde.org");
-
-	KCmdLineArgs::init(argc, argv, &about);
-	KApplication a;
+	aboutData.addAuthor(i18n("George Staikos"), i18n("Primary author and maintainer"), "staikos@kde.org");
 
+    QApplication app(argc, argv);
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    //PORTING SCRIPT: adapt aboutdata variable if necessary
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 	KNetAttach na;
-    a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );
+    app.connect( &app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()) );
 	na.show();
 
-	return a.exec();
+	return app.exec();
 }
